# Laz3

S22 is a powerful encryption algorithm written in lua with customizable maths so every message is locked with a number that can be how long you want!

# Versions
0.0.3
# Example 1

Password: abcd 

Message: "Hello World!"

response: "E8085.0A980.0Z2695.0U2695.0D3430.0G12740.0p11760.0z3430.0c4165.0E2695.0Y735.0Z"

# Example 2

Password: Laz3IsCool! 

Message: "Hello World!"

response: "q29040.0T3520.0J9680.0c9680.0H12320.0B45760.0t42240.0T12320.0n14960.0V9680.0w2640.0J61600.0b"
 
